% reordermat  Transformation matrix for reordering the qudits according to
%             the given pattern.
%    reordermat(pattern,d) gives a transformation matrix for
%    putting the qudits in the order given in pattern.
%    d is the dimension of the qudit. If it is omitted then
%    the default value is 2 (qubits).
%    pattern=[N N-1 N-2 ... 1] does not change the ordering.
%    The numbering of qudits can be give by the expression
%    mkron(b4,b3,b2,b1).

% Copyright (C) 2005  Geza Toth    E.mail: toth@alumni.nd.edu
%
% This program is free software; you can redistribute it and/or
% modify it under the terms of the GNU General Public License
% as published by the Free Software Foundation; see gpl.txt
% of this subroutine package.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, 
% Boston, MA  02110-1301, USA.

function matrix=reordermat(pattern,varargin)

if isempty(varargin),
    % qubits
    base=2;
else
    if length(varargin)~=1,
        error('Wrong number of input arguments.');
    end %if
    base=varargin{1};
end %if

% Pattern: numbers from 1 to N.
% No order changes: patterns = 8 7 6 5 4 3 2 1 

% If it is a row vector, transform it into column vector
[y,x]=size(pattern);
if x>1,
   pattern=pattern.';
end %if

pattern=pattern-1;

N=length(pattern);
matrix=zeros(base^N);
for n=1:base^N
   % Conversion to binary 
   b=dec2base(n-1+base^N,base);
   b=b(2:end);  
   a=[];
   for k=1:length(b)
      a=[a;str2num(b(k))];
   end %for
   matrix(n,sum(base.^pattern.*a)+1)=1;
end %for
